Developing Flit
===============

To get a development installation of Flot itself::

    git clone https://github.com/nexB/flot.git


Testing
-------

To run the tests in separate environments for each available Python version::

    tox

`tox <https://tox.readthedocs.io/en/latest/>`_ has many options.

To run the tests in your current environment, run::

    pytest

